<?php
/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 * Project  Zero
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */

// Initialization common to all operations
// Get configured (as 'theDB' in zero.config) DataManager for data access
$dataManager = data_manager('employee_db');

class Employees {
	/**
	 * List all the employees
	 * @success 200 list of employees
	 * @error 503 database query execution failure
	 * @format application/json
	 * @example
	 * [
	 *    {
	 *       "username":"JohnDoe",
	 *       "firstname":"John",
	 *       "lastname":"Doe",
	 *       "location":"East",
	 *       "phonenumber":"342432432"
	 *    }
	 * ]
	 *
	 */
	function onList() {
		global $dataManager;
		// Retrieve employee records via Query Zero
		$employeeRecords = dataExec($dataManager, "SELECT * FROM employees");
		if ($employeeRecords != null) {
			// Use the zero global context to render the data as JSON
			zput('/request/view', 'JSON');
			zput('/request/json/output', $employeeRecords);
			render_view();
		} else {
			zput('/request/status', 503);
			echo "Database query execution failure";	
		}
	}
	
	/**
	 * Create a new employee
	 * @success 204 Employee cretaed
	 * @error 503 Database query execution failure
	 * @format application/json
	 * @example
	 * {
	 *       "username":"JohnDoe",
	 *       "firstname":"John",
	 *       "lastname":"Doe",
	 *       "location":"East",
	 *       "phonenumber":"342432432"
	 * }
	 *
	 */
	function onCreate() {
		global $dataManager;
		// Convert the raw JSON stream in to a PHP array
		$er = json_decode($HTTP_RAW_POST_DATA);

		$result = dataExec($dataManager, "INSERT INTO employees (username, firstname, lastname, location, phonenumber) ". 
		 	"VALUES (?, ?, ?, ?, ?)", array($er['username'], $er['firstname'], $er['lastname'], $er['location'], $er['phonenumber']));
		 
		// verify that an entry was inserted
		if ($result == 1) {
			// Set a Location header with URI to the new record
			$locationUri = zget('/request/path') . "/" . $er["username"];
			zput('/request/headers/out/Location', $locationUri);
			zput('/request/status', 204);
		} else { 
			zput('/request/status', 503);
			echo "Database query execution failure";
		}
	}
	
	/**
	 * Retrieve a specific employee's details
	 * @success 200 Employee details
	 * @error 404 Employee not found
	 * @format text/json
	 * @example
	 * {
	 *       "username":"JohnDoe",
	 *       "firstname":"John",
	 *       "lastname":"Doe",
	 *       "location":"East",
	 *       "phonenumber":"342432432"
	 * }
	 */
	function onRetrieve() {
		// Get configured DataManager for data access
		global $dataManager;
		
		// Zero puts 'itemId' when accessing restful resources 
		$username = zget("/request/params/employeesId");

		// Retrieve employee record via Query Zero
		$employeeRecord = dataQueryFirst($dataManager, "SELECT * FROM employees WHERE username=?", array($username));

		if(isset($employeeRecord)) {
		  	// JSON encode employee record
			zput('/request/headers/out/Content-Type', 'text/json');  			
		 	echo json_encode($employeeRecord);
		} else {
			// Error handling; return a custom error page
			zput("/request/status", 404);
  			echo "username ". $username . " not found.";
		}
	}
	
	/**
	 * Update the specifics of an employee
	 * @success 204 Employee updated
	 * @error 503 Database query execution failure
	 * @format application/json
	 * @example
	 * {
	 *       "username":"JohnDoe",
	 *       "firstname":"John",
	 *       "lastname":"Doe",
	 *       "location":"East",
	 *       "phonenumber":"342432432"
	 * }
	 */
	function onUpdate() {
		// Get configured DataManager for data access
		global $dataManager;
		
		$employeeId = zget('/request/params/employeesId');
		
		// By convention, Zero places posted text/json into the GC as a JSON object
		$er = json_decode($HTTP_RAW_POST_DATA);

		$result = dataExec($dataManager, "UPDATE employees SET firstname=?, lastname=?, ".
                            "location=?, phonenumber=? WHERE username=?",
                            array($er['firstname'], $er['lastname'], $er['location'], $er['phonenumber'], $employeeId));
        if ($result != null) {
			zput("/request/status", 204);
        } else {
        	zput('/request/status', 503);
        	echo "Database query execution failure";
        }
	}
	
	/**
	 * Delete a specific employee
	 * @success 200 Employee deleted
	 * @error 503 Database query execution failure
	 */
	function onDelete() {
		// Get configured DataManager for data access
		global $dataManager;
		$username = zget("/request/params/employeesId");

		// Delete employee record via Query Zero
		$result = dataExec($dataManager, "DELETE FROM employees WHERE username=?", array($username));

		if ($result != null) {
			zput("/request/status", 204);
		} else {
			zput('/request/status', 503);
			echo "Database query execution failure";
		}
	}
	
}
?>